<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>Lyrics</name>
    <message>
        <location filename="../lyrics.cpp" line="33"/>
        <source>View Lyrics</source>
        <translation>显示歌词</translation>
    </message>
    <message>
        <location filename="../lyrics.cpp" line="34"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
</context>
<context>
    <name>LyricsFactory</name>
    <message>
        <location filename="../lyricsfactory.cpp" line="29"/>
        <source>Lyrics Plugin</source>
        <translation>歌词插件</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="49"/>
        <source>About Lyrics Plugin</source>
        <translation>关于歌词插件</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="50"/>
        <source>Qmmp Lyrics Plugin</source>
        <translation>Qmmp 歌词插件</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="51"/>
        <source>This plugin retrieves lyrics from LyricWiki</source>
        <translation>此插件使用的歌词来源于 LyricWiki</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="53"/>
        <source>Based on Ultimate Lyrics script by Vladimir Brkic &lt;vladimir_brkic@yahoo.com&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LyricsWindow</name>
    <message>
        <location filename="../lyricswindow.ui" line="14"/>
        <source>Lyrics Plugin</source>
        <translation>歌词插件</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="31"/>
        <source>Provider:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="122"/>
        <source>Album:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="139"/>
        <source>Track:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="146"/>
        <source>Artist:</source>
        <translation>艺术家：</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="161"/>
        <source>Year:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="115"/>
        <source>Title:</source>
        <translation>标题：</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="115"/>
        <source>&lt;h2&gt;%1 - %2&lt;/h2&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="126"/>
        <source>Not found</source>
        <translation>没有发现</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="136"/>
        <source>Error: %1 - %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="149"/>
        <source>Receiving</source>
        <translation>接受</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="204"/>
        <source>cache</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Lyrics Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Lyrics providers:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UltimateLyricsParser</name>
    <message>
        <location filename="../ultimatelyricsparser.cpp" line="119"/>
        <source>%1 (line: %2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
